@@ -58,6 +58,7 @@ extern PGDLLEXPORT Datum dbms_alert_waitany(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum dbms_alert_waitone(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum dbms_alert_waitany_maxwait(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum dbms_alert_waitone_maxwait(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum dbms_alert_defered_signal(PG_FUNCTION_ARGS);
 
 /* from assert.c */
 extern PGDLLEXPORT Datum dbms_assert_enquote_literal(PG_FUNCTION_ARGS);
@@ -96,6 +97,8 @@ extern PGDLLEXPORT Datum ora_timestamp_round(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum orafce_sysdate(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum orafce_sessiontimezone(PG_FUNCTION_ARGS);
 extern PGDLLEXPORT Datum orafce_dbtimezone(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum orafce_sys_extract_utc(PG_FUNCTION_ARGS);
+extern PGDLLEXPORT Datum orafce_sys_extract_utc_oracle_date(PG_FUNCTION_ARGS);
 
 /* from file.c */
 extern PGDLLEXPORT Datum utl_file_fopen(PG_FUNCTION_ARGS);
